vector-search.bm25


add-docclj

(add-doc state id text)
source

default-bclj

source

default-k1clj

source

empty-indexclj

(empty-index)
source

remove-docclj

(remove-doc state id)
source

(search state query k {:keys [k1 b ids] :or {k1 default-k1 b default-b}})
source

tokenizeclj

(tokenize text)

Lowercases text and splits it on one or more non-alphanumeric characters.

Lowercases text and splits it on one or more non-alphanumeric characters.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries